pecos.error\_models.old.gatewise\_gen
=====================================

.. automodule:: pecos.error_models.old.gatewise_gen











   .. rubric:: Classes

   .. autosummary::

      GatewiseModel
